@@ -15,22 +15,22 @@
 # MA  02111-1307  USA
 
 
-################################################################################
-.First.lib =
-function(lib, pkg)
-{
+## ################################################################################
+## .First.lib =
+## function(lib, pkg)
+## {
 
-###     # Startup Mesage and Desription:
-###     MSG <- if(getRversion() >= "2.5") packageStartupMessage else message
-###     dsc <- packageDescription(pkg)
-###     if(interactive() || getOption("verbose")) {
-###         # not in test scripts
-###         MSG(sprintf("Rmetrics Package %s (%s) loaded.", pkg, dsc$Version))
-###     }
+## ###     # Startup Mesage and Desription:
+## ###     MSG <- if(getRversion() >= "2.5") packageStartupMessage else message
+## ###     dsc <- packageDescription(pkg)
+## ###     if(interactive() || getOption("verbose")) {
+## ###         # not in test scripts
+## ###         MSG(sprintf("Rmetrics Package %s (%s) loaded.", pkg, dsc$Version))
+## ###     }
 
-    setRmetricsOptions(.x.save = NA)
+##     setRmetricsOptions(.x.save = NA)
 
-}
+## }
 
 
 .onLoad <- function(libname, pkgname) setRmetricsOptions(.x.save = NA)
@@ -41,4 +41,3 @@ if(!exists("Sys.setenv", mode = "function")) # pre R-2.5.0, use "old form"
 
 
 ################################################################################
-
